-- Table principale des électrovannes
CREATE TABLE Electrovannes (
    id INTEGER PRIMARY KEY,
    nom TEXT NOT NULL,
    mode CHAR(1) CHECK(mode IN ('M', 'P', 'A')) NOT NULL
);

-- Mode Manuel : O = Ouvert, F = Fermé
CREATE TABLE ModeManuel (
    electrovanne_id INTEGER PRIMARY KEY,
    etat CHAR(1) CHECK(etat IN ('O', 'F')) NOT NULL,
    FOREIGN KEY(electrovanne_id) REFERENCES Electrovannes(id) ON DELETE CASCADE
);

-- Mode Programmé
CREATE TABLE ModeProgramme (
    id INTEGER PRIMARY KEY,
    electrovanne_id INTEGER NOT NULL,
    date_heure_debut DATETIME NOT NULL,
    duree INTEGER NOT NULL,         -- en minutes
    frequence INTEGER NOT NULL,     -- en jours
    FOREIGN KEY(electrovanne_id) REFERENCES Electrovannes(id) ON DELETE CASCADE
);

-- Mode Automatique
CREATE TABLE ModeAutomatique (
    electrovanne_id INTEGER PRIMARY KEY,
    hygro_min INTEGER NOT NULL,
    hygro_max INTEGER NOT NULL,
    FOREIGN KEY(electrovanne_id) REFERENCES Electrovannes(id) ON DELETE CASCADE
);

-- Insertion des 4 électrovannes en mode Manuel
INSERT INTO Electrovannes (nom, mode) VALUES ('Vanne1', 'M');
INSERT INTO Electrovannes (nom, mode) VALUES ('Vanne2', 'M');
INSERT INTO Electrovannes(nom, mode) VALUES ('Vanne3', 'M');
INSERT INTO Electrovannes (nom, mode) VALUES ('Vanne4', 'M');

-- Mise à l'état Fermé (F) pour toutes les vannes en mode Manuel
INSERT INTO ModeManuel (electrovanne_id, etat)
SELECT id, 'F' FROM Electrovannes WHERE mode = 'M';

